/*
 * Copyright (C) 2009-2011 Andy Spencer <andy753421@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GRITS_H__
#define __GRITS_H__

/* Grits Core */
#include <grits-viewer.h>
#include <grits-opengl.h>
#include <grits-prefs.h>
#include <grits-util.h>

/* Grits data */
#include <data/grits-data.h>
#include <data/grits-http.h>
#include <data/grits-tms.h>
#include <data/grits-wms.h>

/* Grits objects */
#include <objects/grits-object.h>
#include <objects/grits-tile.h>
#include <objects/grits-marker.h>
#include <objects/grits-callback.h>
#include <objects/grits-volume.h>
#include <objects/grits-poly.h>
#include <objects/grits-line.h>

/* Plugins */
#include <grits-plugin.h>

/* Misc */
#include <gtkgl.h>

#endif
